@@ -96,20 +96,6 @@ class DataSet(DataFrame, Generic[T]):
     def filter(self, condition) -> "DataSet[T]":  # pylint: disable=C0116
         return DataSet[self._schema_annotations](super().filter(condition))  # type: ignore
 
-    @overload
-    def intersect(self, other: "DataSet[T]") -> "DataSet[T]":
-        ...  # pragma: no cover
-
-    @overload
-    def intersect(self, other: DataFrame) -> DataFrame:
-        ...  # pragma: no cover
-
-    def intersect(self, other: DataFrame) -> DataFrame:  # pylint: disable=C0116
-        res = super().intersect(other)
-        if isinstance(other, DataSet) and other._schema_annotations == self._schema_annotations:
-            return DataSet[self._schema_annotations](res)  # type: ignore
-        return res  # pragma: no cover
-
     @overload
     def join(
         self,
@@ -163,20 +149,6 @@ class DataSet(DataFrame, Generic[T]):
     ) -> "DataFrame":
         return super().transform(func, *args, **kwargs)
 
-    @overload
-    def union(self, other: "DataSet[T]") -> "DataSet[T]":
-        ...  # pragma: no cover
-
-    @overload
-    def union(self, other: DataFrame) -> DataFrame:
-        ...  # pragma: no cover
-
-    def union(self, other: DataFrame) -> DataFrame:  # pylint: disable=C0116
-        res = super().union(other)
-        if isinstance(other, DataSet) and other._schema_annotations == self._schema_annotations:
-            return DataSet[self._schema_annotations](res)  # type: ignore
-        return res  # pragma: no cover
-
     @overload
     def unionByName(  # noqa: N802  # pylint: disable=C0116, C0103
         self,
